
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.26.18',
    'branch_nick': 'release-1.26-LTS',
    'revision_id': 'a24464cd6692a6b146625d5b0957ae0e233557db',
    'revno': 10952
}
